@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2007 Pedro Castro
+ * Copyright (C) 2007-2008 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@ using Mono.Unix;
 using System;
 using System.Text;
 
-namespace GnomeSubtitles {
+namespace GnomeSubtitles.Core {
 
 public class Encodings {
 
