@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006 Pedro Castro
+ * Copyright (C) 2006-2009 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,13 +19,39 @@
 
 using Gtk;
 using System;
+using System.Diagnostics;
 using System.Globalization;
-using SubLib;
+using System.Threading;
+using SubLib.Core.Domain;
 
-namespace GnomeSubtitles {
+namespace GnomeSubtitles.Core {
 
 public class Util {
   
+  	//TODO move to other util?
+  	public static int ColumnWidth (Widget widget, string text) {
+  		int margins = 10;
+  		return TextWidth(widget, text, margins); 
+    }
+    
+    public static TreeViewColumn CreateTreeViewColumn (string title, int width, CellRenderer cell, TreeCellDataFunc dataFunction) {
+		cell.Xalign = 0.5f;
+		cell.Yalign = 0;
+		TreeViewColumn column = new TreeViewColumn();
+		column.Alignment = 0.5f;
+		column.Title = title;
+		
+		if (width != -1) {
+			column.FixedWidth = width;
+			column.Sizing = TreeViewColumnSizing.Fixed;
+		}
+		
+		column.Resizable = true;
+		column.PackStart(cell, true);
+		column.SetCellDataFunc(cell, dataFunction);
+		return column;
+	}
+  
     public static int TextWidth (Widget widget, string text, int margins) {
     	Pango.Layout layout = widget.CreatePangoLayout(text);
     	int width, height;
@@ -79,39 +105,52 @@ public class Util {
 		args.RetVal = 1;
 	}
 	
-	public static void SetSpinButtonTimingMode (SpinButton spinButton, TimingMode timingMode, bool canNegate) {
+	public static void SetSpinButtonTimingMode (SpinButton spinButton, TimingMode timingMode) {
 		if (timingMode == TimingMode.Frames) {
 			spinButton.Input -= OnTimeInput;
 			spinButton.Output -= OnTimeOutput;
-			spinButton.Adjustment.StepIncrement = 1;
-    		spinButton.Adjustment.Upper = 3000000;
-    		if (canNegate)
-    			spinButton.Adjustment.Lower = -3000000;
 		}
 		else {
 			spinButton.Input += OnTimeInput;
 			spinButton.Output += OnTimeOutput;
-			spinButton.Adjustment.StepIncrement = 100;
-			spinButton.Adjustment.Upper = 86399999;
-			if (canNegate)
-				spinButton.Adjustment.Lower = -86399999;
 		}
 	}
 	
+	public static void SetSpinButtonAdjustment (SpinButton spinButton, TimeSpan upperLimit, bool canNegate) {
+		spinButton.Adjustment.StepIncrement = 100; //milliseconds
+		spinButton.Adjustment.Upper = (upperLimit != TimeSpan.Zero ? upperLimit.TotalMilliseconds : 86399999);
+		spinButton.Adjustment.Lower = (canNegate ? -spinButton.Adjustment.Upper : 0); 
+	}
+	
+	public static void SetSpinButtonAdjustment (SpinButton spinButton, int upperLimit, bool canNegate) {
+		spinButton.Adjustment.StepIncrement = 1; //frame
+		spinButton.Adjustment.Upper = (upperLimit != 0 ? upperLimit : 3000000);
+		spinButton.Adjustment.Lower = (canNegate ? -spinButton.Adjustment.Upper : 0); 
+	}
+	
+	public static void SetSpinButtonMaxAdjustment (SpinButton spinButton, TimingMode timingMode, bool toNegate) {
+		if (timingMode == TimingMode.Times)
+			SetSpinButtonAdjustment(spinButton, TimeSpan.Zero, toNegate);
+		else
+			SetSpinButtonAdjustment(spinButton, 0, toNegate);
+	}
+	
 	public static bool OpenUrl (string url) {
 		if ((url == null) || (url == String.Empty))
 			return false;
 
 		try {
-			Gnome.Url.Show(url);
+			Process process = Process.Start(url);
+			Thread.Sleep(250);
+			return (!process.HasExited);
 		}
-		catch (Exception) { //Exceptions for Url.Show are not documented in the gtk-sharp api
+		catch (Exception) {
 			return false;
 		}
-		
-		return true;
 	}
 	
+	
+	
 	public static bool OpenSendEmail (string email) {
 		return OpenUrl("mailto:" + email);
 	}
@@ -120,6 +159,21 @@ public class Util {
 		return OpenUrl("http://bugzilla.gnome.org/enter_bug.cgi?product=gnome-subtitles");
 	}
 	
+	public static bool IsPathValid (TreePath path) {
+		if (path == null)
+			return false;
+		
+		try {
+			if ((path.Indices == null) || (path.Indices.Length == 0))
+				return false;
+		}
+		catch (Exception) {
+			return false;
+		}
+		
+		return true;
+	}
+	
 	/// <summary>Returns the index of a <see cref="TreePath" />.</summary>
 	public static int PathToInt (TreePath path) {
 		return path.Indices[0];
@@ -131,14 +185,14 @@ public class Util {
 	}
 	
 	/// <summary>Returns an array of <see cref="TreePath" /> from an array of ints.</summary>
-	public static TreePath[] IntsToPaths (int[] indexes) {
-		if (indexes == null)
+	public static TreePath[] IntsToPaths (int[] indices) {
+		if (indices == null)
 			return null;
 		
-		int length = indexes.Length;
+		int length = indices.Length;
 		TreePath[] paths = new TreePath[length];
 		for (int position = 0 ; position < length ; position++) {
-			int index = indexes[position];
+			int index = indices[position];
 			TreePath path = IntToPath(index);
 			paths[position] = path;
 		}
@@ -174,6 +228,13 @@ public class Util {
 	public static string ToString (float number) {
 		return number.ToString(NumberFormatInfo.InvariantInfo);
 	}
+	
+	public static string GetFormattedText (string text, params object[] args) {
+		if ((args == null) || (args.Length == 0))
+			return text;
+		else
+			return String.Format(text, args);
+	}
 
 }
 
